searchNodes=[{"doc":"Elixir introduces into the world of programming, the &quot;multiverse testing&quot; pattern. This is a pattern where integration tests are run concurrently and each test sees a shard of global state. Examples: Mox: each test has access to the global module mock, sharded by the pid of the running test. Ecto: each test has access to a &quot;database sandbox&quot;, which is a checked out transaction on the global database that acts as its own database shard. Hound,Wallaby: each test generates an ID that is passed outside of the BEAM that is reintercepted on ingress, this ID is then used to connect ecto sandboxes to the parent test PID This library irresponsibly abuses macros to implement Multiverses-aware versions of several constructs in the Elixir Standard Library which aren&#39;t natively Multiversable. Why are macros necessary? This entire library should be compile-time-only. We don&#39;t want any of this dreck polluting runtime. Ideally, support for this pattern would be available in the Elixir standard library out of the box (possibly with options), and the hope is that this library can be deprecated altogether. You should be able to read code, reason about it, and most of the time stay in your universe and not worry that Multiverses exist at test time. For plugins that are provided for other systems, see the libraries: :multiverses_finch - which extends this to HTTP requests that exit the BEAM. :multiverses_pubsub - which extends this to Phoenix.PubSub Usage In mix.exs, you should add the following directive: {:multiverses, &quot;~&gt; 0.5.0&quot;, runtime: false} In your module where you&#39;ll be using at least one multiverse module, use the following header: use Multiverses, with: Registry this aliases Multiverses.Registry to Registry and activates the Multiverses.Registry macros across this module. As an escape hatch, if you need to use the underlying module, you may use the macro alias Elixir.Registry If you need more complex choices for when to activate Multiverses (such as system environment variables), you should encode those choices directly using logic around the use Multiverses statement. Options :with the names of multiverse modules you&#39;d like to use. May be a single module or a list of modules. Is identical to require Multiverses.&lt;module&gt;; alias Multiverses.&lt;module&gt;. :otp_app the otp_app must have its :use_multiverses application environment variable set in order to be used. Defaults to autodetecting via Mix.","ref":"Multiverses.html","title":"Multiverses","type":"module"},{"doc":"purges the caller list.","ref":"Multiverses.html#drop/0","title":"Multiverses.drop/0","type":"macro"},{"doc":"generates a &quot;link&quot; to current universe. If you pass the result of &quot;link&quot; to port/1, then it will bring the ported process into the universe of the process that called link/0","ref":"Multiverses.html#link/0","title":"Multiverses.link/0","type":"macro"},{"doc":"this function can identify if a parent module has been overridden with its Multiverse equivalent in this module. Important: the parent_module parameter is interpreted in the global aliasing context, and not in the context of the local alias. useful for making compile-time guarantees, for example in ExUnit Case modules.","ref":"Multiverses.html#overrides?/2","title":"Multiverses.overrides?/2","type":"macro"},{"doc":"causes the current process to adopt the universe referred to by the result of a link/0 call.","ref":"Multiverses.html#port/1","title":"Multiverses.port/1","type":"macro"},{"doc":"identifies the universe of the current process.","ref":"Multiverses.html#self/0","title":"Multiverses.self/0","type":"macro"},{"doc":"","ref":"Multiverses.html#t:link/0","title":"Multiverses.link/0","type":"opaque"},{"doc":"This module is intended to be a drop-in replacement for Application. When you drop this module in, functions relating to runtime environment variables have been substituted with equivalent macros that respect the Multiverse pattern. Warning This module is as dangerous as it is useful, so please make sure you know what you&#39;re doing before you use this. Always test your system in a staging system that has :use_multiverses unset, before deploying code that uses this module. The functions calls which take options (:timeout, :persist) are not supported, since it&#39;s likely that if you&#39;re using these options, you&#39;re probably not in a situation where you need multiverses. For the same reason, :get_all_env and :put_all_env are not supported and will default the Elixir standard.","ref":"Multiverses.Application.html","title":"Multiverses.Application","type":"module"},{"doc":"cloned from Application.__compile_env__/4","ref":"Multiverses.Application.html#__compile_env__/4","title":"Multiverses.Application.__compile_env__/4","type":"macro"},{"doc":"cloned from Application.__compile_env__!/3","ref":"Multiverses.Application.html#__compile_env__!/3","title":"Multiverses.Application.__compile_env__!/3","type":"macro"},{"doc":"cloned from Application.app_dir/1","ref":"Multiverses.Application.html#app_dir/1","title":"Multiverses.Application.app_dir/1","type":"macro"},{"doc":"cloned from Application.app_dir/2","ref":"Multiverses.Application.html#app_dir/2","title":"Multiverses.Application.app_dir/2","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#delete_env/2","title":"Multiverses.Application.delete_env/2","type":"macro"},{"doc":"cloned from Application.delete_env/3","ref":"Multiverses.Application.html#delete_env/3","title":"Multiverses.Application.delete_env/3","type":"macro"},{"doc":"cloned from Application.ensure_all_started/1","ref":"Multiverses.Application.html#ensure_all_started/1","title":"Multiverses.Application.ensure_all_started/1","type":"macro"},{"doc":"cloned from Application.ensure_all_started/2","ref":"Multiverses.Application.html#ensure_all_started/2","title":"Multiverses.Application.ensure_all_started/2","type":"macro"},{"doc":"cloned from Application.ensure_loaded/1","ref":"Multiverses.Application.html#ensure_loaded/1","title":"Multiverses.Application.ensure_loaded/1","type":"macro"},{"doc":"cloned from Application.ensure_started/1","ref":"Multiverses.Application.html#ensure_started/1","title":"Multiverses.Application.ensure_started/1","type":"macro"},{"doc":"cloned from Application.ensure_started/2","ref":"Multiverses.Application.html#ensure_started/2","title":"Multiverses.Application.ensure_started/2","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#fetch_env/2","title":"Multiverses.Application.fetch_env/2","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#fetch_env!/2","title":"Multiverses.Application.fetch_env!/2","type":"macro"},{"doc":"cloned from Application.format_error/1","ref":"Multiverses.Application.html#format_error/1","title":"Multiverses.Application.format_error/1","type":"macro"},{"doc":"cloned from Application.get_all_env/1","ref":"Multiverses.Application.html#get_all_env/1","title":"Multiverses.Application.get_all_env/1","type":"macro"},{"doc":"cloned from Application.get_application/1","ref":"Multiverses.Application.html#get_application/1","title":"Multiverses.Application.get_application/1","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#get_env/2","title":"Multiverses.Application.get_env/2","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#get_env/3","title":"Multiverses.Application.get_env/3","type":"macro"},{"doc":"cloned from Application.load/1","ref":"Multiverses.Application.html#load/1","title":"Multiverses.Application.load/1","type":"macro"},{"doc":"cloned from Application.loaded_applications/0","ref":"Multiverses.Application.html#loaded_applications/0","title":"Multiverses.Application.loaded_applications/0","type":"macro"},{"doc":"cloned from Application.put_all_env/1","ref":"Multiverses.Application.html#put_all_env/1","title":"Multiverses.Application.put_all_env/1","type":"macro"},{"doc":"cloned from Application.put_all_env/2","ref":"Multiverses.Application.html#put_all_env/2","title":"Multiverses.Application.put_all_env/2","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#put_env/3","title":"Multiverses.Application.put_env/3","type":"macro"},{"doc":"cloned from Application.put_env/4","ref":"Multiverses.Application.html#put_env/4","title":"Multiverses.Application.put_env/4","type":"macro"},{"doc":"cloned from Application.spec/1","ref":"Multiverses.Application.html#spec/1","title":"Multiverses.Application.spec/1","type":"macro"},{"doc":"cloned from Application.spec/2","ref":"Multiverses.Application.html#spec/2","title":"Multiverses.Application.spec/2","type":"macro"},{"doc":"cloned from Application.start/1","ref":"Multiverses.Application.html#start/1","title":"Multiverses.Application.start/1","type":"macro"},{"doc":"cloned from Application.start/2","ref":"Multiverses.Application.html#start/2","title":"Multiverses.Application.start/2","type":"macro"},{"doc":"cloned from Application.started_applications/0","ref":"Multiverses.Application.html#started_applications/0","title":"Multiverses.Application.started_applications/0","type":"macro"},{"doc":"cloned from Application.started_applications/1","ref":"Multiverses.Application.html#started_applications/1","title":"Multiverses.Application.started_applications/1","type":"macro"},{"doc":"cloned from Application.stop/1","ref":"Multiverses.Application.html#stop/1","title":"Multiverses.Application.stop/1","type":"macro"},{"doc":"","ref":"Multiverses.Application.html#universe/1","title":"Multiverses.Application.universe/1","type":"macro"},{"doc":"cloned from Application.unload/1","ref":"Multiverses.Application.html#unload/1","title":"Multiverses.Application.unload/1","type":"macro"},{"doc":"This module is intended to be a drop-in replacement for DynamicSupervisor. It launches the supervised process during a slice of time in which the universe of the DynamicSupervisor is temporarily set to the universe of its caller. For example, if the supervised process is Multiverses.GenServer, with start_link option forward_callers: true, then the GenServer will exist in the same universe as its caller. Currently uses DynamicSupervisor private API, so forward compatibility is not guaranteed. Usage This module should only be used at the point of starting a child under the supervisor. All other uses of DynamicSupervisor (such as use DynamicSupervisor) should use the native Elixir DynamicSupervisor module, and the supervisor is fully compatible with native DynamicSupervisor processes. Notes currently, only start_child/2 is overloaded to provide sharded information. count_children/1, terminate_child/2 and which_children/1 will act on the global information. If you need access to partitioned collections of processes, use Multiverse.Registry.","ref":"Multiverses.DynamicSupervisor.html","title":"Multiverses.DynamicSupervisor","type":"module"},{"doc":"cloned from DynamicSupervisor.__struct__/0","ref":"Multiverses.DynamicSupervisor.html#__struct__/0","title":"Multiverses.DynamicSupervisor.__struct__/0","type":"macro"},{"doc":"cloned from DynamicSupervisor.__struct__/1","ref":"Multiverses.DynamicSupervisor.html#__struct__/1","title":"Multiverses.DynamicSupervisor.__struct__/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.child_spec/1","ref":"Multiverses.DynamicSupervisor.html#child_spec/1","title":"Multiverses.DynamicSupervisor.child_spec/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.code_change/3","ref":"Multiverses.DynamicSupervisor.html#code_change/3","title":"Multiverses.DynamicSupervisor.code_change/3","type":"macro"},{"doc":"cloned from DynamicSupervisor.count_children/1","ref":"Multiverses.DynamicSupervisor.html#count_children/1","title":"Multiverses.DynamicSupervisor.count_children/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.format_report/1","ref":"Multiverses.DynamicSupervisor.html#format_report/1","title":"Multiverses.DynamicSupervisor.format_report/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.format_status/2","ref":"Multiverses.DynamicSupervisor.html#format_status/2","title":"Multiverses.DynamicSupervisor.format_status/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.handle_call/3","ref":"Multiverses.DynamicSupervisor.html#handle_call/3","title":"Multiverses.DynamicSupervisor.handle_call/3","type":"macro"},{"doc":"cloned from DynamicSupervisor.handle_cast/2","ref":"Multiverses.DynamicSupervisor.html#handle_cast/2","title":"Multiverses.DynamicSupervisor.handle_cast/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.handle_info/2","ref":"Multiverses.DynamicSupervisor.html#handle_info/2","title":"Multiverses.DynamicSupervisor.handle_info/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.init/1","ref":"Multiverses.DynamicSupervisor.html#init/1","title":"Multiverses.DynamicSupervisor.init/1","type":"macro"},{"doc":"","ref":"Multiverses.DynamicSupervisor.html#start_child/2","title":"Multiverses.DynamicSupervisor.start_child/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.start_link/1","ref":"Multiverses.DynamicSupervisor.html#start_link/1","title":"Multiverses.DynamicSupervisor.start_link/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.start_link/2","ref":"Multiverses.DynamicSupervisor.html#start_link/2","title":"Multiverses.DynamicSupervisor.start_link/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.start_link/3","ref":"Multiverses.DynamicSupervisor.html#start_link/3","title":"Multiverses.DynamicSupervisor.start_link/3","type":"macro"},{"doc":"cloned from DynamicSupervisor.stop/1","ref":"Multiverses.DynamicSupervisor.html#stop/1","title":"Multiverses.DynamicSupervisor.stop/1","type":"macro"},{"doc":"cloned from DynamicSupervisor.stop/2","ref":"Multiverses.DynamicSupervisor.html#stop/2","title":"Multiverses.DynamicSupervisor.stop/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.stop/3","ref":"Multiverses.DynamicSupervisor.html#stop/3","title":"Multiverses.DynamicSupervisor.stop/3","type":"macro"},{"doc":"cloned from DynamicSupervisor.terminate/2","ref":"Multiverses.DynamicSupervisor.html#terminate/2","title":"Multiverses.DynamicSupervisor.terminate/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.terminate_child/2","ref":"Multiverses.DynamicSupervisor.html#terminate_child/2","title":"Multiverses.DynamicSupervisor.terminate_child/2","type":"macro"},{"doc":"cloned from DynamicSupervisor.which_children/1","ref":"Multiverses.DynamicSupervisor.html#which_children/1","title":"Multiverses.DynamicSupervisor.which_children/1","type":"macro"},{"doc":"This module is intended to be a drop-in replacement for use GenServer. Note that this is different from other modules. Usage defmodule MyModule do use Multiverses, with: GenServer use GenServer def start_link(...) do GenServer.start_link(__MODULE__, init, forward_callers: true) end # # standard GenServer code. # end The Multiverses.GenServer implementation introduces a :forward_callers option into the GenServer init, setting this to true, allows the GenServer to inherit the callers chain of its caller. This is compatible with Multiverses.DynamicSupervisor. Important: Typically you won&#39;t want GenServers to default to be part of a multiverse shard, as they generally represent stateful persistent internal services. If the service can exist before and after the test, then you should consider NOT using this module. When you should use this module: In some cases, a GenServer will represent a transient connection, or a cache for state IRL which is tracked in a specific context.","ref":"Multiverses.GenServer.html","title":"Multiverses.GenServer","type":"module"},{"doc":"cloned from GenServer.abcast/2","ref":"Multiverses.GenServer.html#abcast/2","title":"Multiverses.GenServer.abcast/2","type":"macro"},{"doc":"cloned from GenServer.abcast/3","ref":"Multiverses.GenServer.html#abcast/3","title":"Multiverses.GenServer.abcast/3","type":"macro"},{"doc":"cloned from GenServer.call/2","ref":"Multiverses.GenServer.html#call/2","title":"Multiverses.GenServer.call/2","type":"macro"},{"doc":"cloned from GenServer.call/3","ref":"Multiverses.GenServer.html#call/3","title":"Multiverses.GenServer.call/3","type":"macro"},{"doc":"cloned from GenServer.cast/2","ref":"Multiverses.GenServer.html#cast/2","title":"Multiverses.GenServer.cast/2","type":"macro"},{"doc":"cloned from GenServer.format_report/1","ref":"Multiverses.GenServer.html#format_report/1","title":"Multiverses.GenServer.format_report/1","type":"macro"},{"doc":"cloned from GenServer.multi_call/2","ref":"Multiverses.GenServer.html#multi_call/2","title":"Multiverses.GenServer.multi_call/2","type":"macro"},{"doc":"cloned from GenServer.multi_call/3","ref":"Multiverses.GenServer.html#multi_call/3","title":"Multiverses.GenServer.multi_call/3","type":"macro"},{"doc":"cloned from GenServer.multi_call/4","ref":"Multiverses.GenServer.html#multi_call/4","title":"Multiverses.GenServer.multi_call/4","type":"macro"},{"doc":"cloned from GenServer.reply/2","ref":"Multiverses.GenServer.html#reply/2","title":"Multiverses.GenServer.reply/2","type":"macro"},{"doc":"starts a GenServer, linked to the calling function.","ref":"Multiverses.GenServer.html#start/3","title":"Multiverses.GenServer.start/3","type":"macro"},{"doc":"starts a GenServer, linked to the calling function.","ref":"Multiverses.GenServer.html#start_link/3","title":"Multiverses.GenServer.start_link/3","type":"macro"},{"doc":"cloned from GenServer.stop/1","ref":"Multiverses.GenServer.html#stop/1","title":"Multiverses.GenServer.stop/1","type":"macro"},{"doc":"cloned from GenServer.stop/2","ref":"Multiverses.GenServer.html#stop/2","title":"Multiverses.GenServer.stop/2","type":"macro"},{"doc":"cloned from GenServer.stop/3","ref":"Multiverses.GenServer.html#stop/3","title":"Multiverses.GenServer.stop/3","type":"macro"},{"doc":"cloned from GenServer.whereis/1","ref":"Multiverses.GenServer.html#whereis/1","title":"Multiverses.GenServer.whereis/1","type":"macro"},{"doc":"allows a module to directly clone all of the public functions of a given module, except as macros. thus multiverse equivalents replicate the functionality of the parent module, except with the equivalents substituted at compile time, allowing multiverse apps to exist as [runtime: false] apps. Usage In the following example, FooModule has all of its functions ported into the current module, except as macros. The functions FooModule.foo/3 and FooModule.foo/4 are not, but rather should be ported using defclone/2 use Multiverses.MacroClone, with: FooModule, except: [ foo: 3, foo: 4 ]","ref":"Multiverses.MacroClone.html","title":"Multiverses.MacroClone","type":"module"},{"doc":"clones the target function from the parent module (as defined in the use statement) as a macro, unless use Multiverses has been activated. In the case that use Multiverses has been activated, the macro takes the value of the contents inside the defclone block.","ref":"Multiverses.MacroClone.html#defclone/2","title":"Multiverses.MacroClone.defclone/2","type":"macro"},{"doc":"This module is intended to be a drop-in replacement for Registry, though currently not all functionality is implemented. If universes are active, keys in the Registry will be {universe, key} instead of the normal key. A convenience via/2 macro has been provided, which will substitute this in correctly. Unimplemented functionality: count_match/3,4 match/3,4 unregister_match/3,4","ref":"Multiverses.Registry.html","title":"Multiverses.Registry","type":"module"},{"doc":"cloned from Registry.__unregister__/3","ref":"Multiverses.Registry.html#__unregister__/3","title":"Multiverses.Registry.__unregister__/3","type":"macro"},{"doc":"cloned from Registry.child_spec/1","ref":"Multiverses.Registry.html#child_spec/1","title":"Multiverses.Registry.child_spec/1","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#count/1","title":"Multiverses.Registry.count/1","type":"macro"},{"doc":"cloned from Registry.count_match/3","ref":"Multiverses.Registry.html#count_match/3","title":"Multiverses.Registry.count_match/3","type":"macro"},{"doc":"cloned from Registry.count_match/4","ref":"Multiverses.Registry.html#count_match/4","title":"Multiverses.Registry.count_match/4","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#dispatch/4","title":"Multiverses.Registry.dispatch/4","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#keys/2","title":"Multiverses.Registry.keys/2","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#lookup/2","title":"Multiverses.Registry.lookup/2","type":"macro"},{"doc":"cloned from Registry.match/3","ref":"Multiverses.Registry.html#match/3","title":"Multiverses.Registry.match/3","type":"macro"},{"doc":"cloned from Registry.match/4","ref":"Multiverses.Registry.html#match/4","title":"Multiverses.Registry.match/4","type":"macro"},{"doc":"cloned from Registry.meta/2","ref":"Multiverses.Registry.html#meta/2","title":"Multiverses.Registry.meta/2","type":"macro"},{"doc":"cloned from Registry.put_meta/3","ref":"Multiverses.Registry.html#put_meta/3","title":"Multiverses.Registry.put_meta/3","type":"macro"},{"doc":"Registers the calling process with the Registry. Works as Registry.register/3 does.","ref":"Multiverses.Registry.html#register/3","title":"Multiverses.Registry.register/3","type":"macro"},{"doc":"cloned from Registry.register_name/2","ref":"Multiverses.Registry.html#register_name/2","title":"Multiverses.Registry.register_name/2","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#select/2","title":"Multiverses.Registry.select/2","type":"macro"},{"doc":"cloned from Registry.send/2","ref":"Multiverses.Registry.html#send/2","title":"Multiverses.Registry.send/2","type":"macro"},{"doc":"cloned from Registry.start_link/1","ref":"Multiverses.Registry.html#start_link/1","title":"Multiverses.Registry.start_link/1","type":"macro"},{"doc":"cloned from Registry.start_link/2","ref":"Multiverses.Registry.html#start_link/2","title":"Multiverses.Registry.start_link/2","type":"macro"},{"doc":"cloned from Registry.start_link/3","ref":"Multiverses.Registry.html#start_link/3","title":"Multiverses.Registry.start_link/3","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#unregister/2","title":"Multiverses.Registry.unregister/2","type":"macro"},{"doc":"cloned from Registry.unregister_match/3","ref":"Multiverses.Registry.html#unregister_match/3","title":"Multiverses.Registry.unregister_match/3","type":"macro"},{"doc":"cloned from Registry.unregister_match/4","ref":"Multiverses.Registry.html#unregister_match/4","title":"Multiverses.Registry.unregister_match/4","type":"macro"},{"doc":"cloned from Registry.unregister_name/1","ref":"Multiverses.Registry.html#unregister_name/1","title":"Multiverses.Registry.unregister_name/1","type":"macro"},{"doc":"","ref":"Multiverses.Registry.html#update_value/3","title":"Multiverses.Registry.update_value/3","type":"macro"},{"doc":"generates the correct via term to call this registry. if :use_multiverses is activated, then the via term will look like: {:via, Registry, {reg, {universe, key}}} If it&#39;s not, the via term will look like: {:via, Registry, {reg, key}}","ref":"Multiverses.Registry.html#via/2","title":"Multiverses.Registry.via/2","type":"macro"},{"doc":"cloned from Registry.whereis_name/1","ref":"Multiverses.Registry.html#whereis_name/1","title":"Multiverses.Registry.whereis_name/1","type":"macro"},{"doc":"","ref":"MultiversesTest.Replicant.html","title":"MultiversesTest.Replicant","type":"module"},{"doc":"allows you to replicate test module multiple times, forcing them to be run concurrently. This helps prove that the system can be run in parallel without issue.","ref":"MultiversesTest.Replicant.html#defmoduler/2","title":"MultiversesTest.Replicant.defmoduler/2","type":"macro"},{"doc":"Multiverses","ref":"readme.html","title":"Multiverses","type":"extras"},{"doc":"Don&#39;t let Mox, Ecto, Hound and Wallaby have ALL the fun! Wubba dubba lub lub!","ref":"readme.html#multiverses-for-elixir","title":"Multiverses - Multiverses for Elixir.","type":"extras"},{"doc":"add a line into the configuration (typically test.exs): config :my_app, use_multiverses: true If you&#39;d like to drop in multiverse sharding for a given module, You should structure your module as follows: defmodule MyModule do use Multiverses, with: Registry def my_function(...) do # uses Multiverses.Registry when enabled. Registry.unegister(...) end end Some modules which change their implementation, may instead activate themselves via the use directive. For example: defmodule MyServer do use Multiverses.GenServer def start_link(_) do # uses Multiverses.GenServer in GenServer. end end","ref":"readme.html#usage","title":"Multiverses - Usage","type":"extras"},{"doc":"you can activate multiple copies of all the tests by passing the REPLICATION system environment variable: REPLICATION=10 mix test will copy the test modules 10 times over, so multiple versions of the same module could possibly run simultaneously.","ref":"readme.html#testing","title":"Multiverses - Testing","type":"extras"},{"doc":"The package can be installed by adding multiverses to your list of dependencies in mix.exs: def deps do [ {:multiverses, &quot;~&gt; 0.5.0&quot;, runtime: false} ] end Documentation can be found at https://hexdocs.pm/multiverses.","ref":"readme.html#installation","title":"Multiverses - Installation","type":"extras"}]